@@ -363,7 +363,7 @@ int CJobRunner::exec(ECommand cmd, const ItemList &urls, bool destIsSystem)
     itsDestIsSystem=destIsSystem;
     itsUrls=urls;
     if(CMD_INSTALL==cmd)
-        qSort(itsUrls.begin(), itsUrls.end());  // Sort list of fonts so that we have type1 fonts followed by their metrics...
+        std::sort(itsUrls.begin(), itsUrls.end());  // Sort list of fonts so that we have type1 fonts followed by their metrics...
     else if(CMD_MOVE==cmd)
         addEnableActions(itsUrls);
     itsIt=itsUrls.constBegin();
