@@ -35,11 +35,11 @@ class DeviceAutomounterKCM : public KCModule, public Ui::DeviceAutomounterKCM
 
 public:
     explicit DeviceAutomounterKCM(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
-    virtual ~DeviceAutomounterKCM();
+    ~DeviceAutomounterKCM() override;
 
 public slots:
-    void load() Q_DECL_OVERRIDE;
-    void save() Q_DECL_OVERRIDE;
+    void load() override;
+    void save() override;
 
 private slots:
     void enabledChanged();
